<?php 
/*
	WP User Control Widget 1.0
	Contact: Bill Edgar (bill.edgar@oaktondata.com)
	http://www.oaktondata.com/wp-user-control
	
	Copyright (c) 2011, Oakton Data LLC
	All rights reserved.

	Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
	    
	    * Redistributions of source code must retain the above copyright
	      notice, this list of conditions and the following disclaimer.
	    * Redistributions in binary form must reproduce the above copyright
	      notice, this list of conditions and the following disclaimer in the
	      documentation and/or other materials provided with the distribution.
	    * Neither the name of the Oakton Data LLC nor the
	      names of its contributors may be used to endorse or promote products
	      derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
	ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
	DISCLAIMED. IN NO EVENT SHALL Oakton Data LLC BE LIABLE FOR ANY
	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
	
	This is the wp_user_control_widget PHP class file.
*/

if ( !class_exists( 'wp_user_control_Widget' ) ) {
	
	// wp_user_control_widget class
	class wp_user_control_Widget extends wp_SidebarWidget {
			
		/* -------------------------------------------------------------------------*/
		/* Constructor
		/* -------------------------------------------------------------------------*/
		
		/**
		 * Widget constructor method. Must be overridden in child class.
		 */
		function wp_user_control_Widget() {
			// initialize widget
			$this->init( array(
				'widgetDescription' =>	'Customizable user control widget for login, registration, lost password, etc. within sidebar.',
				'widgetLocale' => 		'wp-user-control-widget-locale',
				'widgetName' =>			'WP User Control Widget',
				'widgetSlug' =>			'wp-user-control-widget',
				'widgetStyle' =>		WP_USER_CONTROL_WIDGET_STYLE,
				'widgetStyleHandle' => 	'wp-user-control-widget-style'
				) );
		} // end constructor method
		
		/* -------------------------------------------------------------------------*/
		/* Private Functions
		/* -------------------------------------------------------------------------*/
	    
	    /**
	    *
	    * method to set up default options for widget. Must be overidden by child class.
	    */
	    protected function setUpDefaults() {
	    	$this->defaults = array(
	    		'displayAvatar' =>			'enabled',
	    		'loginButtonLabel' =>		'Login',
	    		'loginTabLabel' =>			'Login',
	    		'resetTabLabel' =>			'Reset',
	    		'resetButtonLabel' =>		'Reset Password',
	    		'registerButtonLabel' =>	'Register',
	    		'registerTabLabel' =>		'Register',
	    		'title' =>					'WP User Control Widget'
	    		);	    
	    }
		
		/* -------------------------------------------------------------------------*/
		/* WP_Widget API Functions
		/* -------------------------------------------------------------------------*/
	    
		/** 
	     * Outputs widget settings form. Overrides WP_Widget::form().  Must be overidden by child class.
	     * 
	     * @param object $instance	array of widget options. 
	     */
		public function form( $instance ) {
			
			// merge instance options with defaults
			$instance = wp_parse_args( ( array ) $instance, $this->defaults );
			
			// output title text field
			$this->outputFormField( array( 
				'class' => 			'widefat',
				'label' =>			'Title ',
				'field' => 			'title',
				'type' => 			'text',
				'value' => 			$instance['title']
				) );
			// output fill background checkbox
			$this->outputFormField( array(
				'label' =>			'Display Avatar ', 
				'field' =>			'displayAvatar',
				'type' => 			'checkbox',
				'value' => 			$instance['displayAvatar']
				) );
			// output login tab label field
			$this->outputFormField( array(
				'class' => 			'widefat',
				'label' =>			'Login Tab Label ',
				'field' => 			'loginTabLabel',
				'type' => 			'text',
				'value' => 			$instance['loginTabLabel']
				) );
			// output login button label field
			$this->outputFormField( array(
				'class' => 			'widefat',
				'label' =>			'Login Button Label ',
				'field' => 			'loginButtonLabel',
				'type' => 			'text',
				'value' => 			$instance['loginButtonLabel']
				) );
			// output reset tab label field
			$this->outputFormField( array(
				'class' => 			'widefat',
				'label' =>			'Reset Tab Label ',
				'field' => 			'resetTabLabel',
				'type' => 			'text',
				'value' => 			$instance['resetTabLabel']
				) );
			// output reset button label field
			$this->outputFormField( array(
				'class' => 			'widefat',
				'label' =>			'Reset Button Label ',
				'field' => 			'resetButtonLabel',
				'type' => 			'text',
				'value' => 			$instance['resetButtonLabel']
				) );
			// output register tab label field
			$this->outputFormField( array(
				'class' => 			'widefat',
				'label' =>			'Register Tab Label ',
				'field' => 			'registerTabLabel',
				'type' => 			'text',
				'value' => 			$instance['registerTabLabel']
				) );
			// output register button label field
			$this->outputFormField( array(
				'class' => 			'widefat',
				'label' =>			'Register Button Label ',
				'field' => 			'registerButtonLabel',
				'type' => 			'text',
				'value' => 			$instance['registerButtonLabel']
				) );
		}
		
		/** 
	     * Processes widget options to be saved. Overrides WP_Widget::update().  Must be overidden by child class.
	     * 
	     * @param object $new_instance	previous instance values before update 
	     * @param object $old_instance  new instance values to be saved via update 
	     * @return object $instance
	     */ 
		public function update( $new_instance, $old_instance ) {
			// set instance to point to old options array
			$instance = $old_instance;
			
			// record new instance values for option keys
			$instance['displayAvatar'] = ( $new_instance['displayAvatar'] == 'enabled' ) ? trim( strip_tags( $new_instance['displayAvatar'] ) ) : 'disabled';
			$this->OPTIONS[$this->number]['displayAvatar'] = $instance['displayAvatar'];
			$instance['loginButtonLabel'] = trim( strip_tags( $new_instance['loginButtonLabel'] ) );
			$this->OPTIONS[$this->number]['loginButtonLabel'] = $instance['loginButtonLabel'];
			$instance['loginTabLabel'] = trim( strip_tags( $new_instance['loginTabLabel'] ) );
			$this->OPTIONS[$this->number]['loginTabLabel'] = $instance['loginTabLabel'];
			$instance['registerButtonLabel'] = trim( strip_tags( $new_instance['registerButtonLabel'] ) );
			$this->OPTIONS[$this->number]['registerButtonLabel'] = $instance['registerButtonLabel'];
			$instance['registerTabLabel'] = trim( strip_tags( $new_instance['registerTabLabel'] ) );
			$this->OPTIONS[$this->number]['registerTabLabel'] = $instance['registerTabLabel'];
			$instance['resetButtonLabel'] = trim( strip_tags( $new_instance['resetButtonLabel'] ) );
			$this->OPTIONS[$this->number]['resetButtonLabel'] = $instance['resetButtonLabel'];
			$instance['resetTabLabel'] = trim( strip_tags( $new_instance['resetTabLabel'] ) );
			$this->OPTIONS[$this->number]['resetTabLabel'] = $instance['resetTabLabel'];
			$instance['title'] = trim( strip_tags( $new_instance['title'] ) );
			$this->OPTIONS[$this->number]['title'] = $instance['title'];
			
			// return updated options array
			return $instance;
		}
		
		/** 
	     * Outputs widget content. Overrides WP_Widget::widget(). Must be overidden by child class.
	     * 
	     * @param array $args		array of form elements 
	     * @param object $instance	widget instance
	     */
		public function widget( $args, $instance ) {
			extract( $args );
			// output custom WP widget wrapper
			echo $before_widget;
			// output title based on option input
			$title = apply_filters( 'widget_title', $instance['title'] );
			$displayAvatar = empty( $instance['displayAvatar'] ) ? $this->defaults['displayAvatar'] : $instance['displayAvatar'];
			$loginButtonLabel = empty( $instance['loginButtonLabel'] ) ? $this->defaults['loginButtonLabel'] : $instance['loginButtonLabel'];
			$loginTabLabel = empty( $instance['loginTabLabel'] ) ? $this->defaults['loginTabLabel'] : $instance['loginTabLabel'];
			$registerButtonLabel = empty( $instance['registerButtonLabel'] ) ? $this->defaults['registerButtonLabel'] : $instance['registerButtonLabel'];
			$registerTabLabel = empty( $instance['registerTabLabel'] ) ? $this->defaults['registerTabLabel'] : $instance['registerTabLabel'];
			$resetButtonLabel = empty( $instance['resetButtonLabel'] ) ? $this->defaults['resetButtonLabel'] : $instance['resetButtonLabel'];
			$resetTabLabel = empty( $instance['resetTabLabel'] ) ? $this->defaults['resetTabLabel'] : $instance['resetTabLabel'];
			
		    // output widget title with WP wrapper
		    if ( !empty( $title ) ) { echo $before_title . $title . $after_title; }
		    // output html
		    try {
		    	?>
    						<div id="login-register-password">
    					
    					<?php global $user_ID, $user_identity; get_currentuserinfo(); if ( !$user_ID ) { ?>
    					
    						<ul class="tabs_login">
    							<li class="active_login"><a href="#tab1_login"><?php echo $loginTabLabel; ?></a></li>
    							<li><a href="#tab2_login"><?php echo $registerTabLabel; ?></a></li>
    							<li><a href="#tab3_login"><?php echo $resetTabLabel; ?></a></li>
    						</ul>
    						<div class="tab_container_login">
    							<div id="tab1_login" class="tab_content_login">
    					
    								<?php $register = $_GET['register']; $reset = $_GET['reset']; if ( $register == true ) { ?>
    					
    								<p>Check your email for the password and then return to log in.</p>
    					
    								<?php } elseif ( $reset == true ) { ?>
    					
    								<p>Check your email to reset your password.</p>
    					
    								<?php } else { ?>
    					
    								<p>Enter your username and password below to login.</p>
    					
    								<?php } ?>
    					
    								<form method="post" action="<?php bloginfo( 'url' ) ?>/wp-login.php" class="wp-user-form">
    									<div class="username">
    										<label for="user_login"><?php _e( 'Username' ); ?>: </label>
    										<input type="text" name="log" value="<?php echo esc_attr( stripslashes($user_login ) ); ?>" id="user_login" tabindex="11" />
    									</div>
    									<div class="password">
    										<label for="user_pass"><?php _e( 'Password' ); ?>: </label>
    										<input type="password" name="pwd" value="" id="user_pass" tabindex="12" />
    									</div>
    									<div class="login_fields">
    										<div class="rememberme">
    											<label for="rememberme">
    												<input type="checkbox" name="rememberme" value="forever" checked="checked" id="rememberme" tabindex="13" /> Remember me
    											</label>
    										</div>
    										<?php do_action( 'login_form' ); ?>
    										<input type="submit" name="user-submit" value="<?php _e( $loginButtonLabel ); ?>" tabindex="14" class="user-submit" />
    										<input type="hidden" name="redirect_to" value="<?php echo $_SERVER['REQUEST_URI']; ?>" />
    										<input type="hidden" name="user-cookie" value="1" />
    									</div>
    								</form>
    							</div>
    							<div id="tab2_login" class="tab_content_login" style="display:none;">
    								<p>Complete the form below to register.</p>
    								<form method="post" action="<?php echo site_url( 'wp-login.php?action=register', 'login_post' ) ?>" class="wp-user-form">
    									<div class="username">
    										<label for="user_login"><?php _e( 'Username' ); ?>: </label>
    										<input type="text" name="user_login" value="<?php echo esc_attr( stripslashes( $user_login)); ?>" id="user_login" tabindex="101" />
    									</div>
    									<div class="password">
    										<label for="user_email"><?php _e( 'Email' ); ?>: </label>
    										<input type="text" name="user_email" value="<?php echo esc_attr( stripslashes( $user_email)); ?>" id="user_email" tabindex="102" />
    									</div>
    									<div class="login_fields">
    										<?php do_action( 'register_form' ); ?>
    										<input type="submit" name="user-submit" value="<?php _e( $registerButtonLabel ); ?>" class="user-submit" tabindex="103" />
    										<?php $register = $_GET['register']; if( $register == true ) { echo '<p>Check your email for the password!</p>'; } ?>
    										<input type="hidden" name="redirect_to" value="<?php echo $_SERVER['REQUEST_URI']; ?>?register=true" />
    										<input type="hidden" name="user-cookie" value="1" />
    									</div>
    								</form>
    							</div>
    							<div id="tab3_login" class="tab_content_login" style="display:none;">
    								<p>Enter your username or email to reset your password.</p>
    								<form method="post" action="<?php echo site_url( 'wp-login.php?action=lostpassword', 'login_post' ) ?>" class="wp-user-form">
    									<div class="username">
    										<label for="user_login" class="hide"><?php _e( 'Username or Email' ); ?>: </label>
    										<input type="text" name="user_login" value="" id="user_login" tabindex="1001" />
    									</div>
    									<div class="login_fields">
    										<?php do_action( 'login_form', 'resetpass' ); ?>
    										<input type="submit" name="user-submit" value="<?php _e( $resetButtonLabel ); ?>" class="user-submit" tabindex="1002" />
    										<?php $reset = $_GET['reset']; if( $reset == true ) { echo '<p>A message will be sent to your email address.</p>'; } ?>
    										<input type="hidden" name="redirect_to" value="<?php echo $_SERVER['REQUEST_URI']; ?>?reset=true" />
    										<input type="hidden" name="user-cookie" value="1" />
    									</div>
    								</form>
    							</div>
    						</div>
    					
    						<?php } else { // is logged in ?>
    					
    						<div class="sidebox">
    							<h3>Welcome, <?php echo $user_identity; ?></h3>
    							<?php global $userdata; get_currentuserinfo(); if ( $displayAvatar === 'enabled' ) { ?>
	    							<div class="usericon">
	    								<?php echo get_avatar( $userdata->ID, 60 ); ?>
	    							</div>
	    						<?php } ?>
    							<div class="userinfo">
    								<p>You&rsquo;re logged in as <strong><?php echo $user_identity; ?></strong></p>
    								<p>
    									<a href="<?php echo wp_logout_url( $_SERVER['REQUEST_URI'] ); ?>">Log out</a> &nbsp;|&nbsp; 
    									<?php if ( current_user_can( 'manage_options' ) ) { 
    														echo '<a href="' . admin_url() . '">' . __( 'Admin' ) . '</a>'; } else { 
    														echo '<a href="' . admin_url() . 'profile.php">' . __( 'Profile' ) . '</a>'; } ?>
    					
    								</p>
    							</div>
    						</div>
    					
    						<?php } ?>
    					
    					</div>
    					<!-- WP User Control Widget JS -->
    					<script type="text/javascript" charset="utf-8">
    						jQuery(document).ready(function() {
    							jQuery(".tab_content_login").hide();
    							jQuery("ul.tabs_login li:first").addClass("active_login").show();
    							jQuery(".tab_content_login:first").show();
    							jQuery("ul.tabs_login li").click(function() {
    								jQuery("ul.tabs_login li").removeClass("active_login");
    								jQuery(this).addClass("active_login");
    								jQuery(".tab_content_login").hide();
    								var activeTab = jQuery(this).find("a").attr("href");
    								if (jQuery.browser.msie) {jQuery(activeTab).show();}
    								else {jQuery(activeTab).show();}
    								return false;
    							});
    						});
    					</script>
    					<!-- WP User Control Widget JS -->
    				<?php 
				
		    } catch ( wp_PluginException $e ) {
		    	echo $e->getError();
		    }
			// output custom WP widget wrapper
			echo $after_widget;
		}
	}
}

// hook into widgets_init action
if ( class_exists( 'wp_user_control_widget' ) ) {
	add_action('widgets_init', create_function('', 'register_widget("wp_user_control_widget");'));
}
?>